Page
Library
Module
Module type
Parameter
Class
Class type
Color_brewery.PaletteSourceFind a color map according to certain characteristics.
Based on colors maps by Cynthia A. Brewer, Penn State. See www.ColorBrewer.org
A color map from which one can extract various color ranges.
rgb_exn m i returns the RGB color range containing i colors from m. If i > length m, Invalid_argument is raised.
rgb_exn m i returns the CMYK color range containing i colors from m. If i > length m, Invalid_argument is raised.
val find :
?ty:[ `Seq | `Div | `Qual ] ->
?blind:[ `Yes | `No | `Maybe ] ->
?print:[ `Yes | `No | `Maybe ] ->
?copy:[ `Yes | `No | `Maybe ] ->
?lcd:[ `Yes | `No | `Maybe ] ->
int ->
t listfind length return the list of palettes that support the desired properties for the length length. Note that the maximum length is 12 and the longer the palette, the less it will satisfy other properties. For properties selected with `Yes `No or `Maybe, setting `No (the default) means one does not care, setting `Maybe selects palettes that maybe (or for sure) satisfy the property and `Yes selects palettes that satisfy the property for sure.
ty, if provided, restricts maps to the color scheme:
`Seq: Sequential scheme`Div: Diverging scheme`Qual: Qualitative schemeblind: the palette should be safe for color blind people.print: the palette is print friendly.copy: the palette is photocopy friendly.lcd: the palette is LCD friendly.Color schemes as described in the paper: Brewer, Cynthia A., Geoffrey W. Hatchard and Mark A. Harrower, 2003, ColorBrewer in Print: A Catalog of Color Schemes for Maps, Cartography and Geographic Information Science 30(1): 5-32.
Medium saturation set with more lightness variation and more classes than Set1 and Set2.